==> haskell-test-framework-leancheck-0.0.4-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-leancheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-leancheck
version:              0.0.4
visibility:           public
id:                   test-framework-leancheck-0.0.4-JnEwGKrkpWyJGwQwpuMkz4
key:                  test-framework-leancheck-0.0.4-JnEwGKrkpWyJGwQwpuMkz4
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  4c8e9df4fce96297e0c927b56d42a1f5
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/test-framework-leancheck-0.0.4

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/test-framework-leancheck-0.0.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-leancheck
hs-libraries:         HStest-framework-leancheck-0.0.4-JnEwGKrkpWyJGwQwpuMkz4
depends:
    base-4.15.1.0 leancheck-0.9.10-85gqWNPLTz0BWM88m44GNp
    test-framework-0.8.2.0-EbGg32XnGpy8PP7dIEZf53

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-leancheck-0.0.4-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-leancheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-leancheck
version:              0.0.4
visibility:           public
id:                   test-framework-leancheck-0.0.4-7oKcSfZGZch59M0Y298UZu
key:                  test-framework-leancheck-0.0.4-7oKcSfZGZch59M0Y298UZu
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  5dc8fb71d7ed7aed5b80a1adf48677c5
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/test-framework-leancheck-0.0.4

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/test-framework-leancheck-0.0.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-leancheck
hs-libraries:         HStest-framework-leancheck-0.0.4-7oKcSfZGZch59M0Y298UZu
depends:
    base-4.15.1.0 leancheck-0.9.10-85gqWNPLTz0BWM88m44GNp
    test-framework-0.8.2.0-F3FYoGwOALyI0UXnwENwbZ

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
